Welcome to Absorbing Random-Walk Centrality’s documentation! — absorbing-centrality documentation

# Welcome to Absorbing Random-Walk Centrality’s documentation!

Contents:

- Overview
  - Absorbing Random-Walk Centrality
- Installation
- Usage
- Reference
  - Computing the centrality of a set
  - Team-selection algorithms
  - Matrix-related functions
  - Preprocessing the graph
  - Exceptions
- Contributing
  - Bug reports
  - Documentation improvements
  - Feature requests and feedback
  - Development
- Authors
- Changelog
  - 0.1 (2015-08-31)

# Indices and tables

- Index
- Module Index
- Search Page